---
title: "Marketing Analysis"
author: "jane doe"
date: "2/1/2021"
relationships:
    - id: eda-python
      label: "proves"
    - id: eda-r
      label: "confirms"
---

Lorem ipsum dolor sit, amet consectetur adipisicing elit. Hic neque sapiente dolorem deleniti soluta corporis ex, dolor porro, ullam sequi illum quidem doloribus numquam totam quas, aliquam sed reprehenderit corrupti debitis ipsa. Vitae odio ea voluptas reprehenderit omnis molestias accusamus, earum tempora aperiam non ab dolorem fugit repellendus optio consequatur pariatur necessitatibus consequuntur quod assumenda natus facere, aspernatur perspiciatis? Molestias earum vel id distinctio nisi rem asperiores quae beatae! Vitae, cumque, deleniti nemo iste illum repellat aut doloribus ab, molestias recusandae debitis quas voluptatibus qui aperiam sapiente! Dolorem officia aliquid incidunt sunt quidem numquam ad veritatis eaque, molestias iure cum.

```{r}
plot(cars)
```
